@@ -11,6 +11,15 @@ def autocomplete_users(ctx, args, incomplete):
         return []
 
 
+def autocomplete_priorities(ctx, args, incomplete):
+    """Get Jira priorities list completion"""
+    try:
+        jira = JiraInstance()
+        return [priority.name for priority in jira.session.priorities() if incomplete in priority.name]
+    except Exception:
+        return []
+
+
 def autocomplete_issues(ctx, args, incomplete):
     """Get Jira issues list completion"""
     try:
